---
title: "TBC1D3 MSA and Phylogeny for Vollger et. al 2021 T2T Segmental Duplication paper."
author: "Xavi_Guitart"
date: "8/30/2021"
output: html_document
---

# Description

Included in this document is a step by step of the TBC1D3 phylogeny included in Figure 4.

# Step 1.

First, TBC1D3 gene models were identified and annotated using Liftoff. This resulted in a gff for each primate assembly

```{bash}
liftoff -dir {output.temp} \
         -f <(echo "locus") \
         -flank 0.1 \
         -sc 0.85 -copies -p {threads} \
         -g {input.gff} -o {output.gff} -u {output.unmapped} \
         {input.t} {input.r}
```

# Step 2.

Next, for each primate assembly and gff, TBC1D3 copies identified and extracted.

```{bash}
#turn gff into bed file for processing
gff3ToGenePred -geneNameAttr=gene_name -useName {input.gff} /dev/stdout | \
    genePredToBigGenePred /dev/stdin /dev/stdout | \
    awk -F $'\t' '{{ t = $4; $4 = $13; $13 = t; print; }}' OFS=$'\t' | \
    bedtools sort -i - > {temp_bed}

#subset bed file exclusively to TBC1D3 copies
awk -v pattern='^(TBC1D3[^0-9])' '($4 ~ pattern || /^#/)' {temp_bed} > {TBC1D3_bed}

#generate fasta file
bedtools getfasta -name+ -s -fi {cur_primate_fasta} -bed {TBC1D3_bed} -fo {cur_primate_TBC1D3_fasta}
```

# Step 3.

Next, remove exonic sequence from TBC1D3 orthologs using mam: http://mam-bio.sourceforge.net/Home

```
mam ${fa_to_mam} \
-sw=100 -ww=1000 \
-program=crossmatch \
-fasta=on \
-exonfile={TBC1D3_exons.fa}
```

# Step 4.

Next, with exon free sequence generate MSA by iterative refinement approach

```
mafft --reorder --maxiterate 1000 --thread 16 {input.fasta} >
        {output.MSA.fasta}
```

# Step 5.

Next, generate phylogeny by maximum likelihood using rapid bootstrapping algorithm described in (104)

```
raxmlHPC-PTHREADS -f a -p 12345 -x 12345 -s {input.fasta} -m GTRGAMMA -# 100 -T 8 -n {output.fasta.name} -o {outgroup.sequence.names}
```
